==> kom%2B%2B-0.5.tar.gz: kom++-0.5/py-clients/Makefile.py <==
# Makefile template for py-clients
# $Id: Makefile.py,v 1.3 1996/05/06 07:35:41 ceder Exp $
# Copyright (C) 1996  Per Cederqvist and Inge Wallin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

# Process this file with python to generate Makefile.in.

from pmg import *
m = komxxmakefile()

m.add_include("../genclasses")
m.add_include("$(top_srcdir)/libconnection")
m.add_include("$(top_srcdir)/libkom++")
m.add_include("$(top_srcdir)/libisc/src")
m.add_include("$(top_srcdir)/libcompat")
m.add_include("$(PY_INCLUDES)")

t = cxx_lib_target("komxx")
t.add("komxxmodule.o")

m.add_target(t, "all")

auto_selectors = ["selector.incl",
		  "selector-errno.incl",
		  "selector-assertion.incl"]

for f in auto_selectors:
    m.add_target(generated_source(f), "source")
    
m.emit()

print """
include $(srcdir)/selector.make
include $(srcdir)/selector-errno.make
include $(srcdir)/selector-assertion.make
"""

==> kom%2B%2B-0.6.tar.gz: kom++-0.6/py-clients/Makefile.py <==
# Makefile template for py-clients
# $Id: Makefile.py,v 1.6 1996/07/09 13:19:31 ceder Exp $
# Copyright (C) 1996  Per Cederqvist and Inge Wallin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

# Process this file with python to generate Makefile.in.

from pmg import *
m = komxxmakefile()

m.add_include("../genclasses")
m.add_include("$(top_srcdir)/libconnection")
m.add_include("$(top_srcdir)/libkom++")
m.add_include("$(top_srcdir)/libisc/src")
m.add_include("$(top_srcdir)/libcompat")
m.add_computed_include("$(PY_INCLUDES)")

t = cxx_lib_target("komxx")
t.add("komxxmodule.o")

m.add_target(t, "all")

auto_selectors = ["selector.incl",
		  "selector-errno.incl",
		  "selector-LyStr-errno.incl",
		  "selector-aggregate.incl",
		  "selector-assertion.incl"]

for f in auto_selectors:
    m.add_target(generated_source(f), "source")
    
m.emit()

print """
include $(srcdir)/selector.make
include $(srcdir)/selector-errno.make
include $(srcdir)/selector-aggregate.make
include $(srcdir)/selector-assertion.make
include $(srcdir)/selector-LyStr-errno.make
"""
